pub trait CacheEntry:
Any
+ Send
+ Sync {
// Required method
fn cost(&self) -> usize;
}Expand description
Cached values expose their memory cost directly to the cache backends.
pub trait CacheEntry:
Any
+ Send
+ Sync {
// Required method
fn cost(&self) -> usize;
}Cached values expose their memory cost directly to the cache backends.